@@ -35,7 +35,7 @@ __copyright__ = 'Copyright 2014-2019 - Block Research Group, ETH Zurich'
 __license__ = 'MIT License'
 __email__ = 'vanmelet@ethz.ch'
 
-__version__ = '0.11.0'
+__version__ = '0.11.2'
 
 
 PY3 = sys.version_info[0] == 3
@@ -184,7 +184,7 @@ def set_precision(precision):
     precision = str(precision)
     d = decimal.Decimal(precision).as_tuple()
     if d.exponent < 0:
-        e = abs(d.exponent)
+        e = - d.exponent
         PRECISION = "{}f".format(e)
 
 
