@@ -2,9 +2,6 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-from compas.geometry.transformations import transform_points
-from compas.geometry.transformations import transform_vectors
-
 from compas.geometry.primitives import Primitive
 from compas.geometry.primitives import Point
 
@@ -125,10 +122,30 @@ class Line(Primitive):
     # factory
     # ==========================================================================
 
+    @classmethod
+    def from_data(cls, data):
+        return cls(data['start'], data['end'])
+
     # ==========================================================================
     # descriptors
     # ==========================================================================
 
+    @property
+    def data(self):
+        """Returns the data dictionary that represents the line.
+
+        Returns
+        -------
+        dict
+            The line's data.
+        """
+        return {'start': list(self.start), 'end': list(self.end)}
+
+    @data.setter
+    def data(self, data):
+        self.start = data['start']
+        self.end = data['end']
+
     @property
     def start(self):
         """Point: the start point."""
@@ -168,6 +185,24 @@ class Line(Primitive):
         v = self.direction * (0.5 * self.length)
         return self.start + v
 
+    @property
+    def data(self):
+        """Returns the data dictionary that represents the line.
+
+        Returns
+        -------
+        dict
+            The line data.
+
+        """
+        return {'start': list(self.start),
+                'end': list(self.end)}
+
+    @classmethod
+    def from_data(cls, data):
+        line = Line(data['start'], data['end'])
+        return line
+
     # ==========================================================================
     # representation
     # ==========================================================================
@@ -259,34 +294,33 @@ class Line(Primitive):
     # transformations
     # ==========================================================================
 
-    def transform(self, matrix):
-        """Transform this ``Plane`` using a given transformation matrix.
+    def transform(self, transformation):
+        """Transform the line.
 
         Parameters
         ----------
-        matrix : list of list
-            The transformation matrix.
-
+        transformation : :class:`Transformation`
+            The transformation used to transform the line.
         """
-        self.start.transform(matrix)
-        self.end.transform(matrix)
+        self.start.transform(transformation)
+        self.end.transform(transformation)
 
-    def transformed(self, matrix):
-        """Return a transformed copy of this ``Line`` using a given transformation matrix.
+    def transformed(self, transformation):
+        """Returns a transformed copy of the current line.
 
         Parameters
         ----------
-        matrix : list of list
-            The transformation matrix.
+        transformation : :class:`Transformation`
+            The transformation used to transform the line.
 
         Returns
         -------
-        Line
-            The transformed copy.
+        :class: `Line`
+            The transformed line.
 
         """
         line = self.copy()
-        line.transform(matrix)
+        line.transform(transformation)
         return line
 
 
@@ -298,11 +332,11 @@ if __name__ == '__main__':
 
     import doctest
 
-    from math import sqrt
-    from math import radians
+    from math import sqrt     # noqa F401
+    from math import radians  # noqa F401
 
-    from compas.geometry import Rotation
-    from compas.geometry import Point
-    from compas.geometry import Vector
+    from compas.geometry import Rotation  # noqa F401
+    from compas.geometry import Point     # noqa F401
+    from compas.geometry import Vector    # noqa F401
 
     doctest.testmod(globs=globals())
