@@ -3,13 +3,10 @@ from __future__ import division
 from __future__ import print_function
 
 from compas.geometry import subtract_vectors
-
-from compas.geometry.primitives import Vector
 from compas.geometry.primitives import Frame
-
+from compas.geometry.primitives import Vector
 from compas.geometry.primitives.shapes import Shape
 
-
 __all__ = ['Box']
 
 
@@ -378,6 +375,10 @@ class Box(Shape):
         """
         return self.data
 
+    def to_vertices_and_faces(self, **kwargs):
+        """Returns a list of vertices and faces"""
+        return self.vertices, self.faces
+
     # ==========================================================================
     # representation
     # ==========================================================================
