@@ -2,8 +2,11 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import compas
+
+if not compas.IPY:
+    from .drx_numpy import *
 
-from .drx_numpy import *
 # from .drx_numba import *
 
 
