@@ -2,8 +2,10 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import compas
 
-from .topop_numpy import *
+if not compas.IPY:
+    from .topop_numpy import *
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
