@@ -48,9 +48,9 @@ class RobotModel(object):
 
     def __init__(self, name, joints=[], links=[], materials=[], **kwargs):
         self.name = name
-        self.joints = joints
-        self.links = links
-        self.materials = materials
+        self.joints = list(joints)
+        self.links = list(links)
+        self.materials = list(materials)
         self.attr = kwargs
         self.root = None
         self._rebuild_tree()
