@@ -40,7 +40,7 @@ def vertex_coloring(adjacency):
 
         import compas
         from compas.datastructures import Network
-        from compas.plotters import NetworkPlotter
+        from compas_plotters import NetworkPlotter
         from compas.topology import vertex_coloring
 
         network = Network.from_obj(compas.get('grid_irregular.obj'))
@@ -113,7 +113,7 @@ if __name__ == "__main__":
 
     import compas
     from compas.datastructures import Network
-    from compas.plotters import NetworkPlotter
+    from compas_plotters import NetworkPlotter
 
     network = Network.from_obj(compas.get('grid_irregular.obj'))
 
