@@ -1,3 +1,4 @@
+
 """
 ********************************************************************************
 compas_blender.artists
@@ -5,7 +6,6 @@ compas_blender.artists
 
 .. currentmodule:: compas_blender.artists
 
-
 Artists for visualising (painting) COMPAS data structures in Blender.
 
 
@@ -17,14 +17,15 @@ Artists for visualising (painting) COMPAS data structures in Blender.
     VolMeshArtist
 
 """
-from __future__ import absolute_import
 
+from .artist import *
 from .meshartist import *
 from .networkartist import *
 from .volmeshartist import *
 
-from . import meshartist
-from . import networkartist
-from . import volmeshartist
+from .artist import __all__ as a
+from .meshartist import __all__ as b
+from .networkartist import __all__ as c
+from .volmeshartist import __all__ as d
 
-__all__ = meshartist.__all__ + networkartist.__all__ + volmeshartist.__all__
+__all__ = a + b + c + d
