@@ -1,11 +1,10 @@
+
 from .vertexartist import *
 from .edgeartist import *
 from .faceartist import *
-from .pathartist import *
 
 from .vertexartist import __all__ as a
 from .edgeartist import __all__ as b
 from .faceartist import __all__ as c
-from .pathartist import __all__ as d
 
-__all__ = a + b + d
+__all__ = a + b + c
